@@ -411,7 +411,9 @@ struct	lex_record *p;
 {
 	register int	c, state = STATE_INITIAL;
 	register struct keyword_info	*q;
+#ifndef __linux__
 	extern double atof();
+#endif /* not __linux__ */
 
 	token_length = 0;
 
